@@ -2,6 +2,7 @@ import json
 import logging
 import os
 import uuid
+import warnings
 from typing import Any, Dict, List, Optional, Union
 
 import __main__ as main
@@ -14,21 +15,24 @@ from .artifact import Artifact, ArtifactSpec
 from .dag import (
     DAG,
     AddOrReplaceOperatorDelta,
+    AirflowEngineConfig,
+    EngineConfig,
     Metadata,
     SubgraphDAGDelta,
     apply_deltas_to_dag,
     validate_overwriting_parameters,
 )
-from .enums import RelationalDBServices, ServiceType
+from .enums import RelationalDBServices, RuntimeType, ServiceType
 from .error import (
     IncompleteFlowException,
     InvalidIntegrationException,
     InvalidUserActionException,
     InvalidUserArgumentException,
 )
-from .flow import Flow
+from .flow import Flow, FlowConfig
 from .flow_run import _show_dag
 from .github import Github
+from .integrations.airflow_integration import AirflowIntegration
 from .integrations.google_sheets_integration import GoogleSheetsIntegration
 from .integrations.integration import IntegrationInfo
 from .integrations.s3_integration import S3Integration
@@ -118,6 +122,18 @@ class Client:
             not "PYTEST_CURRENT_TEST" in os.environ
         )
 
+        # Check if "@ file" in pip freeze requirements and warn user.
+        if not "localhost" in aqueduct_address:
+            skipped_packages = []
+            for requirement in infer_requirements():
+                if "@ file" in requirement:
+                    skipped_packages.append(requirement.split(" ")[0])
+            if len(skipped_packages) > 0:
+                warnings.warn(
+                    "Your local Python environment contains packages installed from the local file system. The following packages won't be installed when running your workflow: "
+                    + ", ".join(skipped_packages)
+                )
+
     def github(self, repo: str, branch: str = "") -> Github:
         """Retrieves a Github object connecting to specified repos and branch.
 
@@ -203,6 +219,7 @@ class Client:
         S3Integration,
         GoogleSheetsIntegration,
         RelationalDBIntegration,
+        AirflowIntegration,
     ]:
         """Retrieves a connected integration object.
 
@@ -219,6 +236,8 @@ class Client:
                 provided integration or the provided integration is of an
                 incompatible type.
         """
+        self._connected_integrations = api_client.__GLOBAL_API_CLIENT__.list_integrations()
+
         if name not in self._connected_integrations.keys():
             raise InvalidIntegrationException("Not connected to integration %s!" % name)
 
@@ -243,6 +262,10 @@ class Client:
                 dag=self._dag,
                 metadata=integration_info,
             )
+        elif integration_info.service == ServiceType.AIRFLOW:
+            return AirflowIntegration(
+                metadata=integration_info,
+            )
         else:
             raise InvalidIntegrationException(
                 "This method does not support loading integration of type %s"
@@ -293,6 +316,7 @@ class Client:
         schedule: str = "",
         k_latest_runs: int = -1,
         artifacts: Optional[List[GenericArtifact]] = None,
+        config: Optional[FlowConfig] = None,
     ) -> Flow:
         """Uploads and kicks off the given flow in the system.
 
@@ -317,6 +341,11 @@ class Client:
                 All the artifacts that you care about computing. These artifacts are guaranteed
                 to be computed. Additional artifacts may also be included as intermediate
                 computation steps. All checks are on the resulting flow are also included.
+            config:
+                An optional set of config fields for this flow.
+                - engine: Specify where this flow should run with one of your connected integrations.
+                We currently support Airflow.
+
         Raises:
             InvalidCronStringException:
                 An error occurred because the supplied schedule is invalid.
@@ -352,7 +381,28 @@ class Client:
             retention_policy=retention_policy,
         )
 
-        flow_id = api_client.__GLOBAL_API_CLIENT__.register_workflow(dag).id
+        if config and config.engine:
+            # This is an Airflow workflow
+            dag.engine_config = EngineConfig(
+                type=RuntimeType.AIRFLOW,
+                airflow_config=AirflowEngineConfig(
+                    integration_id=config.engine._metadata.id,
+                ),
+            )
+            resp = api_client.__GLOBAL_API_CLIENT__.register_airflow_workflow(dag)
+            flow_id, airflow_file = resp.id, resp.file
+
+            file = "{}_airflow.py".format(name)
+            with open(file, "w") as f:
+                f.write(airflow_file)
+            print(
+                """The Airflow DAG file has been downloaded to: {}. 
+                Please copy it to your Airflow server to begin execution.""".format(
+                    file
+                )
+            )
+        else:
+            flow_id = api_client.__GLOBAL_API_CLIENT__.register_workflow(dag).id
 
         url = generate_ui_url(
             api_client.__GLOBAL_API_CLIENT__.construct_base_url(),
