@@ -597,7 +597,7 @@ class TableArtifact(Artifact):
 
         return table_artifact
 
-    def describe(self) -> None:
+    def __str__(self) -> str:
         """Prints out a human-readable description of the table artifact."""
 
         input_operator = self._dag.must_get_operator(with_output_artifact_id=self._artifact_id)
@@ -629,8 +629,15 @@ class TableArtifact(Artifact):
                 ],
             }
         )
-        print(format_header_for_print(f"'{input_operator.name}' Table Artifact"))
-        print(json.dumps(readable_dict, sort_keys=False, indent=4))
+
+        return f"""
+{format_header_for_print(f"'{input_operator.name}' Table Artifact")}
+{json.dumps(readable_dict, sort_keys=False, indent=4)}
+        """
+
+    def describe(self) -> None:
+        """Prints the stringified description of the table artifact to stdout."""
+        print(self.__str__())
 
     def remove_check(self, name: str) -> None:
         """Remove a check on this artifact by name.
